@@ -5,34 +5,20 @@
 
     Test our handling of metadata in files with bibliographic metadata.
 
-    :copyright: Copyright 2007-2011 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
 # adapted from an example of bibliographic metadata at
 # http://docutils.sourceforge.net/docs/user/rst/demo.txt
 
-from util import *
+from util import with_app
 
-from nose.tools import assert_equals
+from nose.tools import assert_equal
 
 
-app = env = None
-warnings = []
-
-def setup_module():
-    # Is there a better way of generating this doctree than manually iterating?
-    global app, env
-    app = TestApp(srcdir='(temp)')
-    env = app.env
-    msg, num, it = env.update(app.config, app.srcdir, app.doctreedir, app)
-    for docname in it:
-        pass
-
-def teardown_module():
-    app.cleanup()
-
-def test_docinfo():
+@with_app('pseudoxml')
+def test_docinfo(app, status, warning):
     """
     Inspect the 'docinfo' metadata stored in the first node of the document.
     Note this doesn't give us access to data stored in subsequence blocks
@@ -40,6 +26,8 @@ def test_docinfo():
     'dedication' blocks, or the 'meta' role. Doing otherwise is probably more
     messing with the internals of sphinx than this rare use case merits.
     """
+    app.builder.build(['metadata'])
+    env = app.env
     exampledocinfo = env.metadata['metadata']
     expecteddocinfo = {
         'author': u'David Goodger',
@@ -61,9 +49,12 @@ def test_docinfo():
         'date': u'2006-05-21',
         'organization': u'humankind',
         'revision': u'4564',
+        'tocdepth': 1,
+        'orphan': u'',
+        'nocomments': u'',
     }
     # I like this way of comparing dicts - easier to see the error.
     for key in exampledocinfo:
-        yield assert_equals, exampledocinfo.get(key), expecteddocinfo.get(key)
+        yield assert_equal, exampledocinfo.get(key), expecteddocinfo.get(key)
     # but then we still have to check for missing keys
-    yield assert_equals, set(expecteddocinfo.keys()), set(exampledocinfo.keys())
+    yield assert_equal, set(expecteddocinfo.keys()), set(exampledocinfo.keys())
